.. _api:

API
===

.. automodule:: morelia
   :members:
   :show-inheritance:

.. automodule:: morelia.matchers
   :members:
   :show-inheritance:

.. automodule:: morelia.formatters
   :members:
   :show-inheritance:

.. automodule:: morelia.decorators
   :members:
   :show-inheritance:

.. automodule:: morelia.config
   :members:
   :show-inheritance:


.. rubric:: Footnotes

.. [#ROS] Rule of Silence - When a program has nothing surprising to say, it should say nothing http://www.faqs.org/docs/artu/ch01s06.html#id2878450
.. [#ROR] Rule of Repair - Repair what you can - but when you must fail, fail noisily and as soon as possible http://www.faqs.org/docs/artu/ch01s06.html#id2878538
